#!/usr/bin/env python
# Created by "Thieu" at 22:36, 19/03/2023 ----------%                                                                               
#       Email: nguyenthieu2102@gmail.com            %                                                    
#       Github: https://github.com/thieu1995        %                         
# --------------------------------------------------%

import os


def string():
    try:
        with open(os.path.dirname(__file__) + "/VERSION", "r", encoding="utf-8") as fh:
            version = fh.read().strip()
            if version:
                return version
    except Exception:
        pass
    return "unknown (git checkout)"



#!/usr/bin/env python
# Created by "Thieu" at 22:23, 19/03/2023 ----------%                                                                               
#       Email: nguyenthieu2102@gmail.com            %                                                    
#       Github: https://github.com/thieu1995        %                         
# --------------------------------------------------%

def english(name="Daniel", show=True):
    if show:
        print(f"Hello: {name}")
    return name


def vietnamese(name="Tien", show=True):
    if show:
        print(f"Xin chao: {name}")
    return name



#!/usr/bin/env python
# Created by "Thieu" at 19:11, 19/03/2023 ----------%                                                                               
#       Email: nguyenthieu2102@gmail.com            %                                                    
#       Github: https://github.com/thieu1995        %                         
# --------------------------------------------------%

import os

files = os.listdir(__path__[0])
modules = (
    x.replace(".py", "") for x in files if x.endswith(".py") and not x.startswith("__")
)
for module in modules:
    __import__("foo." + module)



#!/usr/bin/env python
# Created by "Thieu" at 19:29, 19/03/2023 ----------%
#       Email: nguyenthieu2102@gmail.com            %
#       Github: https://github.com/thieu1995        %
# --------------------------------------------------%

from setuptools import setup
import subprocess
import os

foo_version = (
    subprocess.run(["git", "describe", "--tags"], stdout=subprocess.PIPE)
    .stdout.decode("utf-8")
    .strip()
)

if "-" in foo_version:
    # when not on tag, git describe outputs: "1.3.3-22-gdf81228" pip has gotten strict with version numbers so change it to: "1.3.3+22.git.gdf81228"
    # See: https://peps.python.org/pep-0440/#local-version-segments
    v, i, s = foo_version.split("-")
    foo_version = v + "+" + i + ".git." + s

assert "-" not in foo_version
assert "." in foo_version
assert os.path.isfile("foo/version.py")
with open("foo/VERSION", "w", encoding="utf-8") as fh:
    fh.write("%s\n" % foo_version)


def readme():
    with open("README.md") as f:
        return f.read()


setup(
    name="foodemo3",
    version=foo_version,
    description="My DEMO project",
    long_description=readme(),
    long_description_content_type="text/markdown",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Operating System :: OS Independent",
    ],
    url="https://github.com/thieu1995/foodemo",
    author="thieu",
    author_email="nguyenthieu2102@gmail.com",
    keywords="libdemo docs api documentation foo python yaml",
    license="MIT",
    packages=["foo"],
    package_data={"foo": ["VERSION"]},
    python_requires=">=3.5",
    install_requires=[
        "numpy >= 1.24.2"
    ],
    include_package_data=True,
)



#!/usr/bin/env python
# Created by "Thieu" at 19:14, 19/03/2023 ----------%                                                                               
#       Email: nguyenthieu2102@gmail.com            %                                                    
#       Github: https://github.com/thieu1995        %                         
# --------------------------------------------------%

from foo import speak


def test_english():
    assert speak.english("Natali") == "Natali"


def test_vietnamese():
    assert speak.vietnamese("Linh Nhi") == "Linh Nhi"
